@@ -3,9 +3,9 @@ package jdk.javadoc.internal.tool.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "25.0.1-beta+8-ea" },
-            { "jdk", "25.0.1" },
-            { "release", "25.0.1-beta" },
+            { "full", "25-beta+36-ea" },
+            { "jdk", "25" },
+            { "release", "25-beta" },
         };
     }
 }
